@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+import django
+from django.contrib.sites.models import Site
+from django.db.models import Q
+
 try:
     from collections import Counter
 except ImportError:
@@ -6,7 +10,7 @@ except ImportError:
 
 from django.db import models
 from django.utils.timezone import now
-from parler.managers import TranslationManager
+from parler.managers import TranslationManager, TranslatableQuerySet
 
 
 class TaggedFilterItem(object):
@@ -68,29 +72,24 @@ class TaggedFilterItem(object):
         return sorted(tags, key=lambda x: -x.count)
 
 
-class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
-    use_for_related_fields = True
+class GenericDateQuerySet(TranslatableQuerySet):
     start_date_field = 'date_published'
     end_date_field = 'date_published_end'
     publish_field = 'publish'
 
-    def get_queryset(self, *args, **kwargs):
-        try:
-            return super(GenericDateTaggedManager, self).get_queryset(*args, **kwargs)
-        except AttributeError:
-            return super(GenericDateTaggedManager, self).get_query_set(*args, **kwargs)
+    def on_site(self):
+        return self.filter(Q(sites__isnull=True) | Q(sites=Site.objects.get_current().pk))
 
-    def published(self, queryset=None):
-        queryset = self.published_future(queryset)
+    def published(self):
+        queryset = self.published_future()
         if self.start_date_field:
             return queryset.filter(
                 **{'%s__lte' % self.start_date_field: now()})
         else:
             return queryset
 
-    def published_future(self, queryset=None):
-        if queryset is None:
-            queryset = self.get_queryset().all()
+    def published_future(self):
+        queryset = self.on_site()
         if self.end_date_field:
             qfilter = (
                 models.Q(**{'%s__gte' % self.end_date_field: now()})
@@ -99,9 +98,8 @@ class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
             queryset = queryset.filter(qfilter)
         return queryset.filter(**{self.publish_field: True})
 
-    def archived(self, queryset=None):
-        if queryset is None:
-            queryset = self.get_queryset().all()
+    def archived(self):
+        queryset = self.on_site()
         if self.end_date_field:
             qfilter = (
                 models.Q(**{'%s__lte' % self.end_date_field: now()})
@@ -110,13 +108,40 @@ class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
             queryset = queryset.filter(qfilter)
         return queryset.filter(**{self.publish_field: True})
 
-    def available(self, queryset=None):
-        if queryset is None:
-            queryset = self.get_queryset().all()
-        return queryset.filter(**{self.publish_field: True})
+    def available(self):
+        return self.on_site().filter(**{self.publish_field: True})
 
     def filter_by_language(self, language):
-        return self.get_queryset().active_translations(language_code=language)
+        return self.active_translations(language_code=language).on_site()
+
+
+class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
+    use_for_related_fields = True
+
+    queryset_class = GenericDateQuerySet
+
+    def get_queryset(self, *args, **kwargs):
+        try:
+            return super(GenericDateTaggedManager, self).get_queryset(*args, **kwargs)
+        except AttributeError:  # pragma: no cover
+            return super(GenericDateTaggedManager, self).get_query_set(*args, **kwargs)
+    if django.VERSION < (1, 8):
+        get_query_set = get_queryset
+
+    def published(self):
+        return self.get_queryset().published()
+
+    def available(self):
+        return self.get_queryset().available()
+
+    def archived(self):
+        return self.get_queryset().archived()
+
+    def published_future(self):
+        return self.get_queryset().published_future()
+
+    def filter_by_language(self, language):
+        return self.get_queryset().filter_by_language(language)
 
     def get_months(self, queryset=None):
         """
@@ -124,7 +149,8 @@ class GenericDateTaggedManager(TaggedFilterItem, TranslationManager):
         """
         if queryset is None:
             queryset = self.get_queryset()
-        dates = queryset.values_list(self.start_date_field, flat=True)
+        queryset = queryset.on_site()
+        dates = queryset.values_list(queryset.start_date_field, flat=True)
         dates = [(x.year, x.month) for x in dates]
         date_counter = Counter(dates)
         dates = set(dates)
